@@ -3,11 +3,12 @@
 # Copyright (c) 2019 Red Hat, Inc.
 # Copyright (c) 2019 Tomáš Mráz <tmraz@fedoraproject.org>
 
+from subprocess import call, CalledProcessError
+from tempfile import mkstemp
+
 import ctypes
 import ctypes.util
 import os
-from subprocess import CalledProcessError, call
-from tempfile import mkstemp
 
 from .configgenerator import ConfigGenerator
 
@@ -45,10 +46,7 @@ class NSSGenerator(ConfigGenerator):
         'X448': '',
         'SECP256R1': 'SECP256R1',
         'SECP384R1': 'SECP384R1',
-        'SECP521R1': 'SECP521R1',
-        'MLKEM768-X25519': 'mlkem768x25519',
-        'P256-MLKEM768': 'secp256r1mlkem768',
-        'P384-MLKEM1024': 'secp384r1mlkem1024',
+        'SECP521R1': 'SECP521R1'
     }
 
     cipher_map = {
@@ -100,10 +98,6 @@ class NSSGenerator(ConfigGenerator):
         'RSA-': 'RSA-PKCS',
         'ECDSA-': 'ECDSA',
         'DSA-': 'DSA',
-        'EDDSA-ED25519': 'ED25519',
-        'MLDSA44': 'ML-DSA-44',
-        'MLDSA65': 'ML-DSA-65',
-        'MLDSA87': 'ML-DSA-87',
     }
 
     @classmethod
@@ -146,7 +140,7 @@ class NSSGenerator(ConfigGenerator):
             except KeyError:
                 pass
 
-        no_tls_require_ems = os.getenv('NSS_NO_TLS_REQUIRE_EMS', '0') == '1'
+        no_tls_require_ems = os.getenv('NSS_NO_TLS_REQUIRE_EMS', '1') == '1'
         if policy.enums['__ems'] == 'ENFORCE' and not no_tls_require_ems:
             s = cls.append(s, 'TLS-REQUIRE-EMS')
 
@@ -216,7 +210,7 @@ class NSSGenerator(ConfigGenerator):
             cls.eprint("There is a warning in NSS generated policy")
             cls.eprint(f'Policy:\n{config}')
             return False
-        if ret:
+        elif ret:
             cls.eprint("There is an error in NSS generated policy")
             cls.eprint(f'Policy:\n{config}')
             return False
